package com.ruoyi.mall.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallAboutPrivacy;
import com.ruoyi.mall.service.IMallAboutPrivacyService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 关于我们、隐私Controller
 *
 * @author LCL
 * @date 2023-07-11
 */
@RestController
@RequestMapping("/mall/mallAboutPrivacy")
public class MallAboutPrivacyController extends BaseController
{
    @Resource
    private IMallAboutPrivacyService mallAboutPrivacyService;

    /**
     * 查询关于我们、隐私列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallAboutPrivacy:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallAboutPrivacy mallAboutPrivacy)
    {
        startPage();
        List<MallAboutPrivacy> list = mallAboutPrivacyService.selectMallAboutPrivacyList(mallAboutPrivacy);
        return getDataTable(list);
    }

    /**
     * 导出关于我们、隐私列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallAboutPrivacy:export')")
    @Log(title = "关于我们、隐私", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MallAboutPrivacy mallAboutPrivacy)
    {
        List<MallAboutPrivacy> list = mallAboutPrivacyService.selectMallAboutPrivacyList(mallAboutPrivacy);
        ExcelUtil<MallAboutPrivacy> util = new ExcelUtil<MallAboutPrivacy>(MallAboutPrivacy.class);
        util.exportExcel(response, list, "关于我们、隐私数据");
    }

    /**
     * 获取关于我们、隐私详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallAboutPrivacy:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(mallAboutPrivacyService.selectMallAboutPrivacyById(id));
    }

    /**
     * 新增关于我们、隐私
     */
    @PreAuthorize("@ss.hasPermi('mall:mallAboutPrivacy:add')")
    @Log(title = "关于我们、隐私", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallAboutPrivacy mallAboutPrivacy)
    {
        return toAjax(mallAboutPrivacyService.insertMallAboutPrivacy(mallAboutPrivacy));
    }

    /**
     * 修改关于我们、隐私
     */
    @PreAuthorize("@ss.hasPermi('mall:mallAboutPrivacy:edit')")
    @Log(title = "关于我们、隐私", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallAboutPrivacy mallAboutPrivacy)
    {
        return toAjax(mallAboutPrivacyService.updateMallAboutPrivacy(mallAboutPrivacy));
    }

    /**
     * 删除关于我们、隐私
     */
    @PreAuthorize("@ss.hasPermi('mall:mallAboutPrivacy:remove')")
    @Log(title = "关于我们、隐私", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mallAboutPrivacyService.deleteMallAboutPrivacyByIds(ids));
    }
}
